@@ -4,13 +4,12 @@ from functools import lru_cache
 from json import JSONDecodeError
 from os.path import abspath
 from pathlib import Path
-from subprocess import Popen, TimeoutExpired
-from tempfile import TemporaryFile
+from subprocess import PIPE, CompletedProcess, TimeoutExpired, run
 from typing import Any, Dict, List, Tuple
 
+from fuzzing_cli.fuzz.config import FuzzingOptions
 from fuzzing_cli.fuzz.exceptions import BuildArtifactsError
 from fuzzing_cli.fuzz.ide.generic import Contract, IDEArtifacts, Source
-from fuzzing_cli.fuzz.options import FuzzingOptions
 from fuzzing_cli.util import LOGGER
 
 
@@ -20,13 +19,11 @@ class TruffleArtifacts(IDEArtifacts):
         options: FuzzingOptions,
         targets: List[str],
         build_dir: Path,
+        sources_dir: Path,
         map_to_original_source: bool = False,
     ):
         super(TruffleArtifacts, self).__init__(
-            options,
-            targets,
-            build_dir or Path("./build/contracts"),
-            map_to_original_source,
+            options, targets, build_dir, sources_dir, map_to_original_source
         )
         project_dir = str(Path.cwd().absolute())
         self.build_files_by_source_file = self._get_build_artifacts(self.build_dir)
@@ -46,7 +43,7 @@ class TruffleArtifacts(IDEArtifacts):
         return "truffle-config.js" in files
 
     @property
-    def contracts(self) -> List[Contract]:
+    def contracts(self, only_included: bool = True) -> List[Contract]:
         return self.fetch_data()[0]
 
     @property
@@ -54,12 +51,10 @@ class TruffleArtifacts(IDEArtifacts):
         return self.fetch_data()[1]
 
     @lru_cache(maxsize=1)
-    def fetch_data(self) -> Tuple[List[Contract], Dict[str, Source]]:
+    def process_artifacts(self) -> Tuple[Dict[str, List[Contract]], Dict[str, Source]]:
         result_contracts = {}
         result_sources = {}
         for source_file, contracts in self.build_files_by_source_file.items():
-            if source_file not in self._include:
-                continue
             result_contracts[source_file] = []
             for contract in contracts:
                 ignored_sources = set()
@@ -73,7 +68,7 @@ class TruffleArtifacts(IDEArtifacts):
                     result_contracts[source_file] += [
                         {
                             "sourcePaths": {
-                                i: k
+                                str(i): k
                                 for i, k in enumerate(
                                     self.project_sources[contract["contractName"]]
                                 )
@@ -84,7 +79,7 @@ class TruffleArtifacts(IDEArtifacts):
                             "bytecode": contract["bytecode"],
                             "contractName": contract["contractName"],
                             "mainSourceFile": contract["sourcePath"],
-                            "ignoredSources": list(ignored_sources),
+                            "ignoredSources": list(sorted(ignored_sources)),
                         }
                     ]
                 except KeyError as e:
@@ -110,7 +105,7 @@ class TruffleArtifacts(IDEArtifacts):
                         "source": target_file["source"],
                         "ast": target_file["ast"],
                     }
-        return self.flatten_contracts(result_contracts), result_sources
+        return result_contracts, result_sources
 
     def query_truffle_db(self, query: str, project_dir: str) -> Dict[str, Any]:
         executables = ["truffle", "node_modules/.bin/truffle"]
@@ -120,60 +115,58 @@ class TruffleArtifacts(IDEArtifacts):
             )
             executables.insert(0, self._options.truffle_executable_path)
         _executables = executables[::-1]
-        with TemporaryFile() as stdout_file, TemporaryFile() as stderr_file:
-            while _executables:
-                try:
-                    executable = _executables.pop()
-                    LOGGER.debug(f'Invoking truffle executable at path "{executable}"')
-                    # here we're using the tempfile to overcome the subprocess.PIPE's buffer size limit (65536 bytes).
-                    # This limit becomes a problem on a large sized output which will be truncated, resulting to an invalid json
-                    with Popen(
-                        [executable, "db", "query", f"{query}"],
-                        stdout=stdout_file,
-                        stderr=stderr_file,
-                        cwd=project_dir,
-                    ) as p:
-                        p.communicate(timeout=3 * 60)
-                    if stdout_file.tell() == 0:
-                        error = ""
-                        if stderr_file.tell() > 0:
-                            stderr_file.seek(0)
-                            error = str(stderr_file.read())
-                        LOGGER.debug(
-                            f'Empty response from the Truffle DB.\nQuery: "{query}" \nError: {error}'
-                        )
-                        return {}
+        while _executables:
+            try:
+                executable = _executables.pop()
+                LOGGER.debug(f'Invoking truffle executable at path "{executable}"')
+                # here we're using the tempfile to overcome the subprocess.PIPE's buffer size limit (65536 bytes).
+                # This limit becomes a problem on a large sized output which will be truncated, resulting to an invalid json
 
-                    stdout_file.seek(0)
-                    result = json.load(stdout_file)
-                    if not result.get("data"):
-                        LOGGER.debug(
-                            f'Empty response from the Truffle DB.\nQuery: "{query}" \nRaw response: {stdout_file.read()}'
-                        )
-                        return {}
-                    return result.get("data")
-                except FileNotFoundError:
-                    # try next executable path
-                    continue
-                except JSONDecodeError:
-                    stdout_file.seek(0)
-                    LOGGER.debug(
-                        f'JSONDecodeError. \nQuery: "{query}" \nRaw response: {stdout_file.read()}'
-                    )
-                except TimeoutExpired:
-                    LOGGER.debug(f'Truffle DB query timeout.\nQuery: "{query}"')
-                except Exception as e:
-                    stdout_file.seek(0)
-                    LOGGER.debug(
-                        f'Truffle DB query error.\nQuery: "{query}". \nRaw result: {stdout_file.read()}\nError: {e}'
-                    )
+                process: CompletedProcess = run(
+                    [executable, "db", "query", f"{query}"],
+                    stdout=PIPE,
+                    stderr=PIPE,
+                    cwd=project_dir,
+                    timeout=3 * 60,
+                )
+            except FileNotFoundError:
+                # try next executable path
+                continue
+            except TimeoutExpired:
+                LOGGER.debug(f'Truffle DB query timeout.\nQuery: "{query}"')
                 return {}
 
-            raise BuildArtifactsError(
-                f"Truffle DB connection error. Tried executable at paths: {executables}. "
-                f"Please make sure truffle is installed properly or provide path "
-                f"to a truffle executable using `--truffle-path` option to `fuzz run`"
-            )
+            raw_response = process.stdout.decode()
+
+            if len(raw_response) == 0:
+                LOGGER.debug(
+                    f'Empty response from the Truffle DB.\nQuery: "{query}" \nError: "{process.stderr.decode()}"'
+                )
+                return {}
+
+            try:
+                result = json.loads(raw_response)
+                if not result.get("data"):
+                    LOGGER.debug(
+                        f'Empty response from the Truffle DB.\nQuery: "{query}" \nRaw response: "{raw_response}"'
+                    )
+                    return {}
+                return result.get("data")
+            except JSONDecodeError:
+                LOGGER.debug(
+                    f'JSONDecodeError. \nQuery: "{query}" \nRaw response: "{raw_response}"'
+                )
+            except Exception as e:
+                LOGGER.debug(
+                    f'Truffle DB query error.\nQuery: "{query}". \nRaw response: "{raw_response}"\nError: "{e}"'
+                )
+            return {}
+
+        raise BuildArtifactsError(
+            f"Truffle DB connection error. Tried executable at paths: {executables}. "
+            f"Please make sure truffle is installed properly or provide path "
+            f"to a truffle executable using `--truffle-path` option to `fuzz run`"
+        )
 
     def _get_project_sources(self, project_dir: str) -> Dict[str, List[str]]:
         result = self.query_truffle_db(
@@ -234,9 +227,9 @@ class TruffleArtifacts(IDEArtifacts):
         return contracts
 
     @staticmethod
-    def get_default_build_dir() -> str:
-        return "build/contracts"
+    def get_default_build_dir() -> Path:
+        return Path.cwd().joinpath("build/contracts")
 
     @staticmethod
-    def get_default_sources_dir() -> str:
-        return "contracts"
+    def get_default_sources_dir() -> Path:
+        return Path.cwd().joinpath("contracts")
